@@ -480,9 +480,15 @@ our %notfound = (
     'whois.int.ru'          => 'No entries found',
     'whois.reg.ru'          => '^Domain \S+ not found',
 
-    'whois.com.ua'		=> '^% No entries found for domain \S+',
-    'whois.biz.ua'		=> 'No entries found',
-    
+    'whois.com.ua'          => 'No entries found for',
+    'whois.biz.ua'          => 'No entries found',
+    'whois.net.ua'            => 'No entries found for domain',
+    'delta.hostmaster.net.ua' => 'No entries found for domain',
+    'whois.pp.ua'             => 'No entries found',
+    'whois.dn.ua'             => 'No match record found',
+    'whois.lg.ua'             => 'No match record found',
+    'whois.od.ua'             => 'No match record found',
+
     'whois.aero'                 => '^NOT FOUND',
     'whois.nic.asia'             => '^NOT FOUND',
     'whois.biz'                  => '^Not found:',
@@ -523,7 +529,7 @@ our %notfound = (
     'whois.nic.cl'            => '\: no existe',
     'whois.nic.cx'            => 'Status\: Not Registered',
     'whois.nic.cz'            => 'No data found',
-    'whois.denic.de'          => 'No entries found',
+    'whois.denic.de'          => 'Status\: free',
     'whois.nic.dm'            => 'Status\: Not Registered',
     'whois.dk-hostmaster.dk'  => '^No entries found for',
     'whois.eenet.ee'          => '^NOT FOUND',
@@ -583,14 +589,6 @@ our %notfound = (
     'whois.tonic.to'          => 'No match for',
     'whois.twnic.net'         => 'No Found',
     'whois.twnic.net.tw'      => '^No Found',    
-    'whois.net.ua'            => 'No entries found for domain',
-    'delta.hostmaster.net.ua' => 'No entries found for domain',
-    'whois.com.ua'            => 'No entries found for domain',
-    'whois.biz.ua'            => 'No entries found',
-    'whois.pp.ua'             => 'No entries found',
-    'whois.dn.ua'             => 'No match record found',
-    'whois.lg.ua'             => 'No match record found',
-    'whois.od.ua'             => 'No match record found',
     'whois.nic.uk'            => 'No match for',
     'whois.ja.net'            => '^No such domain',
     'whois.nic.us'            => '^Not found',
